--- time-date.el	2024-06-22 21:51:21
+++ time-date_new.el	2024-07-04 11:16:22
@@ -406,10 +406,62 @@
         (list (* 3600 24 400) "d" (* 3600.0 24.0))
         (list nil "y" (* 365.25 24 3600)))
   "Formatting used by the function `seconds-to-string'.")
+
+(defvar seconds-to-string-readable
+  `(("Y" "year"   "years"   ,(round (* 60 60 24 365.2425)))
+    ("M" "month"  "months"  ,(round (* 60 60 24 30.436875)))
+    ("w" "week"   "weeks"   ,(* 60 60 24 7))
+    ("d" "day"    "days"    ,(* 60 60 24))
+    ("h" "hour"   "hours"   ,(* 60 60))
+    ("m" "minute" "minutes" 60)
+    ("s" "second" "seconds" 1))
+  "Formatting used by the function `seconds-to-string' with READABLE set.")
+
 ;;;###autoload
-(defun seconds-to-string (delay)
-  "Convert the time interval in seconds to a short string."
-  (cond ((> 0 delay) (concat "-" (seconds-to-string (- delay))))
+(defun seconds-to-string (delay &optional readable abbrev half)
+  "Convert time interval DELAY (in seconds) to a short string.
+By default, the returned string has two decimal precision in the
+smallest unit that is larger than DELAY from the variable
+`seconds-to-string'.  If READABLE is non-nil, convert DELAY into
+a readable string, using the information in the variable
+`seconds-to-string-readable'.  If it is the symbol `expanded',
+use two units to describe DELAY, if appropriate.  E.g. \"1 hour
+32 minutes\".  If ABBREV is non-nil, abbreviate the readable
+units.  If HALF is non-nil, round the smallest unit displayed to
+the nearest half unit."
+  (cond ((> 0 delay) (concat "-" (seconds-to-string (- delay) readable half)))
+        (readable
+         (let* ((stsa seconds-to-string-readable)
+		(expanded (eq readable 'expanded))
+		(round-to (if half 0.5 1))
+		(padding (if abbrev "" " "))
+		here cnt cnt-pre here-pre)
+	   (if (= (round delay round-to) 0)
+	       (format "0%s" (if abbrev "s" " seconds"))
+	     (while (and (setq here (pop stsa)) stsa
+			 (< (/ delay (nth 3 here)) 1)))
+	     (or (and expanded stsa
+		      (progn
+			(setq here-pre here here (car stsa)
+			      cnt-pre (floor (/ (float delay) (nth 3 here-pre)))
+			      cnt (round (/ (- (float delay) (* cnt-pre (nth 3 here-pre)))
+					    (nth 3 here))
+					 round-to))
+			(if (> cnt 0) t (setq here-pre nil))))
+	       (setq cnt (round (/ (float delay) (nth 3 here)) round-to)))
+	     (cl-labels
+		 ((unit (cnt here &optional half)
+		    (cond (abbrev (car here))
+			  ((<= cnt (if half 2 1)) (nth 1 here))
+			  (t (nth 2 here)))))
+	       (concat
+		(when here-pre
+		  (concat (number-to-string cnt-pre) padding
+			  (unit cnt-pre here-pre) " "))
+		(let ((c (if half (/ cnt 2) cnt)))
+		  (if (> c 0) (number-to-string c) ""))
+		(if (and half (= (mod cnt 2) 1)) "½" "")
+		padding (unit cnt here half))))))
         ((= 0 delay) "0s")
         (t (let ((sts seconds-to-string) here)
              (while (and (car (setq here (pop sts)))
